# Charge Amps API bindings for Python

This repository contains a Python module for the Charge Amps' electric vehicle charging stations.

The module is developed by [Kirei AB](https://www.kirei.se) and is not supported by [Charge Amps AB](https://chargeamps.com).


## External API Key

You need an API key to use the Charge Amps external API. Contact [Charge Amps Support](mailto:support@chargeamps.com) for extensive API documentation and API key.


## References

- [Charge Amps External REST API](https://eapi.charge.space/swagger/)
